==> isddc-1.11.1-py3-none-any.whl: isddc/isddc_dbpool.py <==
import sys

from dbutils.pooled_db import PooledDB

from . import idec
from . import isddc_mysql as imysql

__default__: PooledDB


@idec.TryExcept(Exception, mark='InitDBPool')
@idec.Retry('InitDBPool', count=10, cycle=10)
def __init__(params: dict) -> PooledDB:
    """
    :param: creator
    数据库模块名称

    :param: mincached
        初始化时，连接池中至少创建的空闲的连接，0表示不创建

    :param: maxcached
        连接池中最多闲置的连接，0和None表示不限制

    :param: maxshared
        连接池中最多共享的连接数量，0和None表示全部共享（这个参数不管指定多少，最后都会是0）
        因为pymysql和MySQLdb等模块的threadsafety都为1，
        所以值无论设置为多少，_maxshared永远为0，所以永远是所有连接都共享

    :param: maxconnections
        连接池允许的最大连接数，0和None表示不限制连接数

    :param: blocking
        连接池中如果没有可用连接后，是否阻塞等待，True:等待 False:不等待，直接报错

    :param: maxusage
        一个连接最多可被使用的次数，None表示无限制

    :param: setsession
        开始会话前执行的命令列表，如: ['set dtype to ...', 'set time zone ...']

    :param: ping
        Ping MySQL服务端，检查服务是否可用
        0: 从来没有  1: 从池中提取时（默认） 2: 创建游标时  4: 执行查询时  7: 总是

    :param: *args **kwargs
        数据库膜拜参数
    """
    params.creator = sys.modules[params.creator]
    return PooledDB(**params)


class mysql(imysql.Transaction):

    def __new__(
            cls,
            sql: str = None,
            *,
            one: bool = False,
            dtype=dict,
            pool: PooledDB = None
    ):
        """Is execute sql"""
        if sql is None or isinstance(sql, PooledDB):
            return object.__new__(cls)

        pool = pool or __default__

        conn = pool.connection()
        conn.ping(reconnect=True)

        cur = conn.cursor(cls._dtype[dtype])

        result: int = cur.execute(sql)

        conn.commit()
        # You should execute the `conn.commit()`,
        # even if the SQL is `select ...`,
        # otherwise this connection will not be able to
        # query the data written by other connections.

        if not sql.lstrip()[:6].upper().startswith('SELECT'):
            return result

        queryset = cur.fetchall()

        if dtype is dict:
            queryset = cls.__upgrade_dtype__(cls, queryset)

        cur.close()

        conn.close()
        # This is not to close the connection, but to
        # return the connection to the connection pool.

        return queryset[0] if one else queryset

    def __init__(
            self,
            sql=None,
            *,
            one: bool = False,
            dtype=dict,
            pool: PooledDB = None
    ):
        pool = sql or pool or __default__

        self.conn = pool.connection()
        self.cur = self.conn.cursor(self._dtype[dtype])
        self.dtype = dtype

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if exc_type or exc_val or exc_tb:
            self.conn.rollback()
        self.conn.commit()
        self.cur.close()
        self.conn.close()

==> isddc-3.1.0-py3-none-any.whl: isddc/isddc_dbpool.py <==
import sys

try:
    from dbutils.pooled_db import PooledDB
except ModuleNotFoundError:
    PooledDB = None

from . import isddc_decorator as idec
from . import isddc_mysql     as imysql

__default__: PooledDB


@idec.TryExceptAsync(Exception, name='InitDBPool')
@idec.RetryAsync('InitDBPool', count=10, cycle=10)
async def __init__(params: dict) -> PooledDB:
    """
    :param: creator
    数据库模块名称

    :param: mincached
        初始化时，连接池中至少创建的空闲的连接，0表示不创建

    :param: maxcached
        连接池中最多闲置的连接，0和None表示不限制

    :param: maxshared
        连接池中最多共享的连接数量，0和None表示全部共享（这个参数不管指定多少，最后都会是0）
        因为pymysql和MySQLdb等模块的threadsafety都为1，
        所以值无论设置为多少，_maxshared永远为0，所以永远是所有连接都共享

    :param: maxconnections
        连接池允许的最大连接数，0和None表示不限制连接数

    :param: blocking
        连接池中如果没有可用连接后，是否阻塞等待，True:等待 False:不等待，直接报错

    :param: maxusage
        一个连接最多可被使用的次数，None表示无限制

    :param: setsession
        开始会话前执行的命令列表，如: ['set dtype to ...', 'set time zone ...']

    :param: ping
        Ping MySQL服务端，检查服务是否可用
        0: 从来没有  1: 从池中提取时（默认） 2: 创建游标时  4: 执行查询时  7: 总是

    :param: *args **kwargs
        数据库膜拜参数
    """
    params.creator = sys.modules[params.creator]
    return PooledDB(**params)


class mysql(imysql.Transaction):

    def __new__(
            cls,
            sql: str = None,
            *,
            one: bool = False,
            dtype=dict,
            pool: PooledDB = None
    ):
        """Is execute sql"""
        if sql is None:
            return object.__new__(cls)

        pool = pool or __default__

        conn = pool.connection()
        conn.ping(reconnect=True)

        cur = conn.cursor(cls._dtype[dtype])

        result: int = cur.execute(sql)

        conn.commit()
        # You should execute the `conn.commit()`,
        # even if the SQL is `select ...`,
        # otherwise this connection will not be able to
        # query the data written by other connections.

        if not sql.lstrip()[:6].upper().startswith('SELECT'):
            return result

        queryset = cur.fetchall()

        if dtype is dict:
            queryset = cls.upgrade_dtype(cls, queryset)

        cur.close()

        conn.close()
        # This is not to close the connection, but to
        # return the connection to the connection pool.

        return queryset[0] if one else queryset

    def __init__(
            self,
            sql=None,
            *,
            one=False,
            dtype=dict,
            pool: PooledDB = None
    ):
        pool = pool or __default__

        self.conn = pool.connection()
        self.cur = self.conn.cursor(self._dtype[dtype])
        self.dtype = dtype

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if exc_type or exc_val or exc_tb:
            self.conn.rollback()
        self.conn.commit()
        self.cur.close()
        self.conn.close()
